@@ -46,6 +46,14 @@ Examples of easily understood moments are “8:30” and “2019-01-01, 8:30”.
 		"not_yet_departed": "Not yet departed",
 		"canceled_explanation": "For canceled trains this means: should have departed by now",
 
+		"day_of_week_0": "Monday",
+		"day_of_week_1": "Tuesday",
+		"day_of_week_2": "Wednesday",
+		"day_of_week_3": "Thursday",
+		"day_of_week_4": "Friday",
+		"day_of_week_5": "Saturday",
+		"day_of_week_6": "Sunday",
+
 		"help": """clirail: command line interface to iRail
 
 Usage:
@@ -104,6 +112,14 @@ Voorbeelden van gemakkelijk te begrijpen momenten zijn “8:30” en “2019-01-
 		"not_yet_departed": "Nog niet vertrokken",
 		"canceled_explanation": "Voor afgeschafte treinen betekent dit: had nu al vertrokken moeten zijn",
 
+		"day_of_week_0": "maandag",
+		"day_of_week_1": "dinsdag",
+		"day_of_week_2": "woensdag",
+		"day_of_week_3": "donderdag",
+		"day_of_week_4": "vrijdag",
+		"day_of_week_5": "zaterdag",
+		"day_of_week_6": "zondag",
+
 		"help": """clirail: commandolijninterface voor iRail
 
 Syntaxis:
