@@ -5,6 +5,7 @@
 from datetime import datetime, date
 from .messages import t
 import re
+from itertools import chain
 
 
 icons = [
@@ -158,9 +159,19 @@ def print_connection_item(item, max_duration_len, max_delay_len):
 			via_arr = via["arrival"]
 			via_ref = substring_from_last(via_dep["vehicle"], ".")
 
+			print((
+				(" " * max_duration_len) + " └→ {time}{delay:>{max_delay_len}}\x1b[38;5;245m  {via}.{platform:2}\x1b[0m"
+			).format(
+				max_delay_len=max_delay_len,
+				via=pad_trunc(via["station"] + " ", 20, "."),
+				platform=pad_trunc(" " + via_arr["platform"], 3, ".", left=False),
+				time=format_time(via_arr["time"]),
+				delay=format_delay(via_arr["delay"])
+			))
+
 			if int(via_dep.get("walking")):
 				print((
-					(" " * max_duration_len) + " ├\x1b[38;5;245m→ {time}{delay:>{max_delay_len}}\x1b[38;5;245m  {via}. 🚶 {go_to_next_station}\x1b[0m"
+					(" " * max_duration_len) + " ┌→ {time}{delay:>{max_delay_len}}\x1b[38;5;245m  {via}. 🚶 {go_to_next_station}\x1b[0m"
 				).format(
 					max_delay_len=max_delay_len,
 					via=pad_trunc(via["station"] + " ", 20, "."),
@@ -170,7 +181,7 @@ def print_connection_item(item, max_duration_len, max_delay_len):
 				))
 			else:
 				print((
-					(" " * max_duration_len) + " ├\x1b[38;5;245m← {time}{delay:>{max_delay_len}}\x1b[38;5;245m  {via}.{platform:2} {ref} {icon} {direction}\x1b[0m"
+					(" " * max_duration_len) + " ┌← {time}{delay:>{max_delay_len}}\x1b[38;5;245m  {via}.{platform:2} {ref} {icon} {direction}\x1b[0m"
 				).format(
 					max_delay_len=max_delay_len,
 					via=pad_trunc(via["station"] + " ", 20, "."),
@@ -235,9 +246,15 @@ def print_connections(connections):
 		for item in connections["connection"]
 	), default=0), len(t("duration")))
 
-	max_delay_len = max((
-		max_delay_str_length(item)
-		for item in connections["connection"]
+	max_delay_len = max(chain(
+		(
+			max_delay_str_length(item)
+			for cs in connections["connection"]
+			for item in cs.get("vias", {}).get("via", [])
+		), (
+			max_delay_str_length(item)
+			for item in connections["connection"]
+		)
 	), default=0)
 
 	print("\x1b[4;3m{duration:>{max_duration_len}} {dep_arr:>8} {delay_spaces} {station:12} {platform:>11} {train:>10}    {towards}\x1b[0m".format(
